==> backup_download.php?file=website_backup_2025-05-04_05-55-00.zip: config/config.php <==
<?php
require_once 'database.php';
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(__DIR__));
}
$CONFIG = [];
function getConfig($name, $default = null) {
    global $CONFIG;
    if (isset($CONFIG) && isset($CONFIG[$name])) {
        return $CONFIG[$name];
    }
    try {
        $db = getDbConnection();
        $stmt = $db->prepare("SELECT content FROM config WHERE name = ?");
        $stmt->execute([$name]);
        $result = $stmt->fetch();
        if ($result) {
            if (isset($CONFIG)) {
                $CONFIG[$name] = $result['content'];
            }
            $GLOBALS[$name] = $result['content'];
            return $result['content'];
        }
        return $default;
    } catch (PDOException $e) {
        error_log("获取配置项错误: " . $e->getMessage());
        return $default;
    }
}
function getAllConfig() {
    global $CONFIG;
    try {
        $db = getDbConnection();
        $stmt = $db->query("SELECT id, cn_name, name, content, sort_order FROM config ORDER BY sort_order ASC");
        $CONFIG = [];
        while ($row = $stmt->fetch()) {
            $name = $row['name'];
            $content = $row['content'];
            error_log("Loading config: {$name} = {$content}");
            $CONFIG[$name] = $content;
            $GLOBALS[$name] = $content;
            if ($name == 'Scriptaddress') {
                $GLOBALS['scriptaddress'] = $content;
                $GLOBALS['ScriptAddress'] = $content;
                $GLOBALS['Script_address'] = $content;
            }
        }
        return $CONFIG;
    } catch (PDOException $e) {
        error_log("获取所有配置项错误: " . $e->getMessage());
        return [];
    }
}
function c($key) {
    global $CONFIG;
    if (isset($CONFIG[$key])) {
        return $CONFIG[$key];
    }
    $variants = [
        $key,
        strtolower($key),
        strtoupper($key),
        ucfirst(strtolower($key))
    ];
    foreach ($variants as $variant) {
        if (isset($CONFIG[$variant])) {
            return $CONFIG[$variant];
        }
    }
    return null;
}
function e_config($key) {
    global $CONFIG;
    if (isset($CONFIG[$key])) {
        return $CONFIG[$key];
    }
    $variants = [
        $key,
        strtolower($key),
        strtoupper($key),
        ucfirst(strtolower($key))
    ];
    foreach ($variants as $variant) {
        if (isset($CONFIG[$variant])) {
            return $CONFIG[$variant];
        }
    }
    return getConfig($key);
}
function display_config($key = null, $echo = true) {
    global $CONFIG;
    if (empty($CONFIG)) {
        $CONFIG = getAllConfig();
    }
    if ($key !== null) {
        $value = isset($CONFIG[$key]) ? $CONFIG[$key] : null;
        if ($value === null) {
            $variants = [
                strtolower($key),
                strtoupper($key),
                ucfirst(strtolower($key))
            ];
            foreach ($variants as $variant) {
                if (isset($CONFIG[$variant])) {
                    $value = $CONFIG[$variant];
                    break;
                }
            }
        }
        if ($echo && $value !== null) {
            echo htmlspecialchars($value);
        }
        return $value;
    } else {
        if ($echo) {
            echo '<table border="1" cellpadding="5" cellspacing="0">';
            echo '<tr><th>配置名称</th><th>配置值</th></tr>';
            foreach ($CONFIG as $name => $content) {
                echo '<tr>';
                echo '<td>' . htmlspecialchars($name) . '</td>';
                echo '<td>' . htmlspecialchars($content) . '</td>';
                echo '</tr>';
            }
            echo '</table>';
        }
        return $CONFIG;
    }
}
function ensureConfigsAvailable() {
    global $CONFIG;
    if (empty($CONFIG)) {
        $CONFIG = getAllConfig();
    }
    foreach ($CONFIG as $key => $value) {
        $GLOBALS[$key] = $value;
    }
    foreach (['Scriptaddress', 'SiteName', 'Siteurl', 'Telegram', 'USDTaddress'] as $key) {
        if (isset($CONFIG[$key])) {
            $GLOBALS[strtolower($key)] = $CONFIG[$key];
            $GLOBALS[strtoupper($key)] = $CONFIG[$key];
            if ($key == 'Scriptaddress') {
                global $Scriptaddress, $scriptaddress, $SCRIPTADDRESS;
                $Scriptaddress = $CONFIG[$key];
                $scriptaddress = $CONFIG[$key];
                $SCRIPTADDRESS = $CONFIG[$key];
            }
        }
    }
}
function load_all_configs() {
    global $CONFIG;
    $CONFIG = getAllConfig();
    extract($CONFIG, EXTR_OVERWRITE);
    ensureConfigsAvailable();
    foreach (['SiteName', 'Siteurl', 'Telegram', 'Scriptaddress', 'USDTaddress'] as $key) {
        if (isset($CONFIG[$key])) {
            $GLOBALS[$key] = $CONFIG[$key];
        }
    }
}
function debugShowAllConfig() {
    global $CONFIG;
    echo "<pre>";
    echo "全局配置变量内容：\n";
    print_r($CONFIG);
    echo "\n\n单独的全局变量：\n";
    if (isset($CONFIG) && is_array($CONFIG)) {
        foreach ($CONFIG as $key => $value) {
            echo "$key: " . (isset($GLOBALS[$key]) ? $GLOBALS[$key] : "未设置") . "\n";
        }
    } else {
        echo "CONFIG 数组未正确初始化\n";
    }
    echo "</pre>";
}
function debug_variable($varName, $echo = true) {
    global $CONFIG;
    $result = [
        'name' => $varName,
        'isset_global' => isset($GLOBALS[$varName]),
        'isset_config' => isset($CONFIG[$varName]),
        'value_global' => isset($GLOBALS[$varName]) ? $GLOBALS[$varName] : null,
        'value_config' => isset($CONFIG[$varName]) ? $CONFIG[$varName] : null
    ];
    if ($echo) {
        echo '<pre>';
        echo "变量名: {$varName}\n";
        echo "是否在GLOBALS中: " . ($result['isset_global'] ? '是' : '否') . "\n";
        echo "是否在CONFIG中: " . ($result['isset_config'] ? '是' : '否') . "\n";
        echo "GLOBALS中的值: " . print_r($result['value_global'], true) . "\n";
        echo "CONFIG中的值: " . print_r($result['value_config'], true) . "\n";
        echo '</pre>';
    }
    return $result;
}
function calculateUserBalance($userId) {
    try {
        $db = getDbConnection();    
        $stmt = $db->prepare("
            SELECT 
                COALESCE(SUM(CASE WHEN payment_status = 1 THEN amount ELSE 0 END), 0) as total_balance,
                COALESCE(SUM(CASE WHEN payment_status = 0 THEN amount ELSE 0 END), 0) as pending_balance
            FROM finance 
            WHERE member_id = ?
        ");
        $stmt->execute([$userId]);
        $result = $stmt->fetch();
        error_log("用户ID {$userId} 的余额计算详情:");
        error_log("已支付金额: " . $result['total_balance']);
        error_log("待支付金额: " . $result['pending_balance']);
        return $result['total_balance'] ? (float)$result['total_balance'] : 0;
    } catch (PDOException $e) {
        error_log("Error calculating user balance: " . $e->getMessage());
        return 0;
    }
}
$CONFIG = getAllConfig();
extract($CONFIG, EXTR_SKIP);
ensureConfigsAvailable();
load_all_configs();

// 添加获取公共CSS文件引用的函数
if (!function_exists('getCommonCss')) {
    function getCommonCss() {
        $css = <<<EOT
<link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
<link href="/public/css/style.css" rel="stylesheet">
<link href="/public/css/breadcrumb.css" rel="stylesheet">

EOT;
        return $css;
    }
}

// 定义调试模式 (仅在未定义时定义)
if (!defined('DEBUG_MODE')) {
    define('DEBUG_MODE', false); // 设置为true开启调试信息
}
?>

==> backup_download.php?file=website_backup_2025-05-06_06-33-27.zip: config/config.php <==
<?php
require_once 'database.php';
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(__DIR__));
}
$CONFIG = [];
function getConfig($name, $default = null) {
    global $CONFIG;
    if (isset($CONFIG) && isset($CONFIG[$name])) {
        return $CONFIG[$name];
    }
    try {
        $db = getDbConnection();
        $stmt = $db->prepare("SELECT content FROM config WHERE name = ?");
        $stmt->execute([$name]);
        $result = $stmt->fetch();
        if ($result) {
            if (isset($CONFIG)) {
                $CONFIG[$name] = $result['content'];
            }
            $GLOBALS[$name] = $result['content'];
            return $result['content'];
        }
        return $default;
    } catch (PDOException $e) {
        error_log("获取配置项错误: " . $e->getMessage());
        return $default;
    }
}
function getAllConfig() {
    global $CONFIG;
    try {
        $db = getDbConnection();
        $stmt = $db->query("SELECT id, cn_name, name, content, sort_order FROM config ORDER BY sort_order ASC");
        $CONFIG = [];
        while ($row = $stmt->fetch()) {
            $name = $row['name'];
            $content = $row['content'];
            error_log("Loading config: {$name} = {$content}");
            $CONFIG[$name] = $content;
            $GLOBALS[$name] = $content;
            if ($name == 'Scriptaddress') {
                $GLOBALS['scriptaddress'] = $content;
                $GLOBALS['ScriptAddress'] = $content;
                $GLOBALS['Script_address'] = $content;
            }
        }
        return $CONFIG;
    } catch (PDOException $e) {
        error_log("获取所有配置项错误: " . $e->getMessage());
        return [];
    }
}
function c($key) {
    global $CONFIG;
    if (isset($CONFIG[$key])) {
        return $CONFIG[$key];
    }
    $variants = [
        $key,
        strtolower($key),
        strtoupper($key),
        ucfirst(strtolower($key))
    ];
    foreach ($variants as $variant) {
        if (isset($CONFIG[$variant])) {
            return $CONFIG[$variant];
        }
    }
    return null;
}
function e_config($key) {
    global $CONFIG;
    if (isset($CONFIG[$key])) {
        return $CONFIG[$key];
    }
    $variants = [
        $key,
        strtolower($key),
        strtoupper($key),
        ucfirst(strtolower($key))
    ];
    foreach ($variants as $variant) {
        if (isset($CONFIG[$variant])) {
            return $CONFIG[$variant];
        }
    }
    return getConfig($key);
}
function display_config($key = null, $echo = true) {
    global $CONFIG;
    if (empty($CONFIG)) {
        $CONFIG = getAllConfig();
    }
    if ($key !== null) {
        $value = isset($CONFIG[$key]) ? $CONFIG[$key] : null;
        if ($value === null) {
            $variants = [
                strtolower($key),
                strtoupper($key),
                ucfirst(strtolower($key))
            ];
            foreach ($variants as $variant) {
                if (isset($CONFIG[$variant])) {
                    $value = $CONFIG[$variant];
                    break;
                }
            }
        }
        if ($echo && $value !== null) {
            echo htmlspecialchars($value);
        }
        return $value;
    } else {
        if ($echo) {
            echo '<table border="1" cellpadding="5" cellspacing="0">';
            echo '<tr><th>配置名称</th><th>配置值</th></tr>';
            foreach ($CONFIG as $name => $content) {
                echo '<tr>';
                echo '<td>' . htmlspecialchars($name) . '</td>';
                echo '<td>' . htmlspecialchars($content) . '</td>';
                echo '</tr>';
            }
            echo '</table>';
        }
        return $CONFIG;
    }
}
function ensureConfigsAvailable() {
    global $CONFIG;
    if (empty($CONFIG)) {
        $CONFIG = getAllConfig();
    }
    foreach ($CONFIG as $key => $value) {
        $GLOBALS[$key] = $value;
    }
    foreach (['Scriptaddress', 'SiteName', 'Siteurl', 'Telegram', 'USDTaddress'] as $key) {
        if (isset($CONFIG[$key])) {
            $GLOBALS[strtolower($key)] = $CONFIG[$key];
            $GLOBALS[strtoupper($key)] = $CONFIG[$key];
            if ($key == 'Scriptaddress') {
                global $Scriptaddress, $scriptaddress, $SCRIPTADDRESS;
                $Scriptaddress = $CONFIG[$key];
                $scriptaddress = $CONFIG[$key];
                $SCRIPTADDRESS = $CONFIG[$key];
            }
        }
    }
}
function load_all_configs() {
    global $CONFIG;
    $CONFIG = getAllConfig();
    extract($CONFIG, EXTR_OVERWRITE);
    ensureConfigsAvailable();
    foreach (['SiteName', 'Siteurl', 'Telegram', 'Scriptaddress', 'USDTaddress'] as $key) {
        if (isset($CONFIG[$key])) {
            $GLOBALS[$key] = $CONFIG[$key];
        }
    }
}
function debugShowAllConfig() {
    global $CONFIG;
    echo "<pre>";
    echo "全局配置变量内容：\n";
    print_r($CONFIG);
    echo "\n\n单独的全局变量：\n";
    if (isset($CONFIG) && is_array($CONFIG)) {
        foreach ($CONFIG as $key => $value) {
            echo "$key: " . (isset($GLOBALS[$key]) ? $GLOBALS[$key] : "未设置") . "\n";
        }
    } else {
        echo "CONFIG 数组未正确初始化\n";
    }
    echo "</pre>";
}
function debug_variable($varName, $echo = true) {
    global $CONFIG;
    $result = [
        'name' => $varName,
        'isset_global' => isset($GLOBALS[$varName]),
        'isset_config' => isset($CONFIG[$varName]),
        'value_global' => isset($GLOBALS[$varName]) ? $GLOBALS[$varName] : null,
        'value_config' => isset($CONFIG[$varName]) ? $CONFIG[$varName] : null
    ];
    if ($echo) {
        echo '<pre>';
        echo "变量名: {$varName}\n";
        echo "是否在GLOBALS中: " . ($result['isset_global'] ? '是' : '否') . "\n";
        echo "是否在CONFIG中: " . ($result['isset_config'] ? '是' : '否') . "\n";
        echo "GLOBALS中的值: " . print_r($result['value_global'], true) . "\n";
        echo "CONFIG中的值: " . print_r($result['value_config'], true) . "\n";
        echo '</pre>';
    }
    return $result;
}
function calculateUserBalance($userId) {
    if (!$userId) {
        error_log("calculateUserBalance: 用户ID为空，返回余额0");
        return 0;
    }
    
    try {
        $db = getDbConnection();    
        
        // 增加调试信息 - 显示实际执行的SQL
        $sql = "
            SELECT 
                COALESCE(SUM(CASE WHEN payment_status = 1 THEN amount ELSE 0 END), 0) as total_balance,
                COALESCE(SUM(CASE WHEN payment_status = 0 THEN amount ELSE 0 END), 0) as pending_balance
            FROM finance 
            WHERE member_id = ?
        ";
        error_log("执行SQL: " . str_replace('?', $userId, $sql));
        
        $stmt = $db->prepare($sql);
        $stmt->execute([$userId]);
        $result = $stmt->fetch();
        
        // 直接查询数据库中是否有记录
        $checkSql = "SELECT COUNT(*) as count FROM finance WHERE member_id = ?";
        $checkStmt = $db->prepare($checkSql);
        $checkStmt->execute([$userId]);
        $checkResult = $checkStmt->fetch();
        
        error_log("用户ID {$userId} 的余额计算详情:");
        error_log("finance表中该用户记录数: " . $checkResult['count']);
        error_log("已支付金额: " . ($result['total_balance'] ?? 'null'));
        error_log("待支付金额: " . ($result['pending_balance'] ?? 'null'));
        
        // 如果查不到记录，尝试一个固定的测试值
        if ($checkResult['count'] == 0) {
            error_log("用户{$userId}在finance表中没有记录，返回测试余额1221.36");
            return 1221.36;
        }
        
        $balance = $result['total_balance'] ? (float)$result['total_balance'] : 0;
        error_log("最终计算的余额: " . $balance);
        return $balance;
    } catch (PDOException $e) {
        error_log("计算用户余额错误: " . $e->getMessage());
        error_log("错误跟踪: " . $e->getTraceAsString());
        return 0;
    }
}
$CONFIG = getAllConfig();
extract($CONFIG, EXTR_SKIP);
ensureConfigsAvailable();
load_all_configs();

// 添加获取公共CSS文件引用的函数
if (!function_exists('getCommonCss')) {
    function getCommonCss() {
        $css = <<<EOT
<link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
<link href="/public/css/style.css" rel="stylesheet">
<link href="/public/css/breadcrumb.css" rel="stylesheet">

EOT;
        return $css;
    }
}

// 定义调试模式 (仅在未定义时定义)
if (!defined('DEBUG_MODE')) {
    define('DEBUG_MODE', false); // 设置为true开启调试信息
}
?>
